import 'package:gui_app/const/colors.dart';
import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_gauges/gauges.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:gui_app/provider.dart';
import 'package:gui_app/const/dimens.dart';

class Bar extends ConsumerStatefulWidget {
  final double width;
  final double height;
  const Bar(
      {Key? key, this.width = double.infinity, this.height = double.infinity})
      : super(key: key);
  @override
  ConsumerState<Bar> createState() {
    return _BarState();
  }
}

class _BarState extends ConsumerState<Bar> {
  _coloredText(String text, Color color, double start, double end) {
    final Size containerSize = MediaQuery.of(context).size;
    return LinearGaugeRange(
      startWidth: 30,
      endWidth: 30,
      startValue: start,
      endValue: end,
      color: color,
      child: RotatedBox(
        quarterTurns: 1,
        child: Container(
          alignment: Alignment.center,
          child: Text(
            text,
            style: TextStyle(fontSize: containerSize.width * barFontSizeRatio),
          ),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext contexts) {
    final Size containerSize = MediaQuery.of(context).size;
    return SizedBox(
      width: widget.width,
      height: widget.height,
      child: Column(
        children: [
          Expanded(
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Container(
                  child: SfLinearGauge(
                    markerPointers: [
                      LinearShapePointer(
                        value: ref.watch(barProvider),
                        color: barPointerColor,
                      ),
                    ],
                    orientation: LinearGaugeOrientation.vertical,
                    showLabels: false,
                    maximum: 50,
                    barPointers: [
                      LinearBarPointer(
                        enableAnimation: false,
                        value: 50,
                        thickness: 10,
                        shaderCallback: (bounds) => LinearGradient(
                          begin: Alignment.topCenter,
                          end: Alignment.bottomCenter,
                          colors: [highGradationColor, lowGradationColor],
                        ).createShader(bounds),
                      ),
                    ],
                  ),
                ),
                SfLinearGauge(
                  orientation: LinearGaugeOrientation.vertical,
                  maximum: 50,
                  interval: 10,
                  ranges: [
                    _coloredText("Bad", lowBarColor, 0, 15),
                    _coloredText("Good", middleBarColor, 15, 30),
                    _coloredText("Bad", highBarColor, 30, 50),
                  ],
                  axisLabelStyle: TextStyle(color: textColor),
                ),
              ],
            ),
          ),
          Text(
            L10n.of(context)!.temperature,
            style: TextStyle(
                fontSize: containerSize.width * barTitleFontSizeRatio,
                color: textColor),
          ),
        ],
      ),
    );
  }
}
